pub struct ApplyConflict {
pub subtask_id: String,
pub files: Vec<String>,
pub detail: String,
}Expand description
A patch that failed to apply during union integration, attributed to its subtask and the files its patch targets (parsed from the patch headers).
Fields
subtask_id: Stringfiles: Vec<String>detail: StringTrait Implementations
Sourceimpl Clone for ApplyConflict
impl Clone for ApplyConflict
Sourceimpl Debug for ApplyConflict
impl Debug for ApplyConflict
impl Eq for ApplyConflict
Sourceimpl From<&ApplyConflict> for ApplyConflictDto
impl From<&ApplyConflict> for ApplyConflictDto
Sourcefn from(c: &ApplyConflict) -> Self
fn from(c: &ApplyConflict) -> Self
Converts to this type from the input type.
Sourceimpl PartialEq for ApplyConflict
impl PartialEq for ApplyConflict
impl StructuralPartialEq for ApplyConflict