pub struct TaskScope;Expand description
Scoped execution with task-local agent context.
Implementations
Sourceimpl TaskScope
impl TaskScope
Sourcepub async fn run<F, T>(ctx: AgentContext, f: F) -> Twhere
F: Future<Output = T>,
pub async fn run<F, T>(ctx: AgentContext, f: F) -> Twhere
F: Future<Output = T>,
Run a future with the given agent context set as task-local.
Sourcepub fn try_with<F, R>(f: F) -> Option<R>where
F: FnOnce(&AgentContext) -> R,
pub fn try_with<F, R>(f: F) -> Option<R>where
F: FnOnce(&AgentContext) -> R,
Try to access the current task’s agent context. Returns None if not running inside a TaskScope.
Sourcepub fn agent_name() -> Option<String>
pub fn agent_name() -> Option<String>
Get the current agent name, if inside a task scope.